pyMez.Code.FrontEnds API documentation
Description: The FrontEnds Subpackage is designed to hold gui's a fuctioning webserver, etc that tie together all...

Top

# pyMez.Code.FrontEnds module

The FrontEnds Subpackage is designed to hold gui's a fuctioning webserver, etc that tie together all the functionality contained in pyMez. This subpackage is assumed to import all other subpackages in pyMez. Currently, there are 3 front ends targeted by pyMez: A wxPython set of windows like frontends, a Django websever based frontend and finaly a jupyter notebook front end.

## Examples

    >>python AdvancedInterfaceFrame.py

FrontEnds

## Import Structure

FrontEnds typically import from all python subpackages

## Help

`pyMez.Code`

Documentation Home | API Documentation Home | Examples | Index

Show source ≡

    """
    The FrontEnds Subpackage is designed to hold gui's a fuctioning webserver, etc that tie together all the functionality
    contained in pyMez. This subpackage is assumed to import all other subpackages in pyMez. Currently, there
    are 3 front ends targeted by pyMez: A wxPython set of windows like frontends, a Django websever based frontend and
    finaly a jupyter notebook front end.

     Examples
    --------
        #!python
        >>python AdvancedInterfaceFrame.py

    <a href="../../../Examples/FrontEnds_Example.html"> FrontEnds </a>

    Import Structure
    ----------------
    FrontEnds typically import from all python subpackages

    Help
    -----
    <a href="../index.html">`pyMez.Code`</a>
    <div>
    <a href="../../../pyMez_Documentation.html">Documentation Home</a> |
    <a href="../../index.html">API Documentation Home</a> |
    <a href="../../../Examples/html/Examples_Home.html">Examples</a> |
    <a href="../../../Reference_Index.html">Index </a>
    </div>
    """

## Sub-modules

pyMez.Code.FrontEnds.AdvancedInterfaceFrame

Advanced wx.Frame with standard containers for interface and control this is meant as a template for GUI design and a test bed for pyMez

## Help

`pyMez.Code.FrontEnds`

Documentation Home | <a href="../../i...

pyMez.Code.FrontEnds.BasicInterfaceFrame

Advanced wx.Frame with standard containers for interface and control this is meant as a template for GUI design and a test bed for pyMez

## Help

`pyMez.Code.FrontEnds`

Documentation Home | <a href="../../i...

pyMez.Code.FrontEnds.EndOfDayDialog

pyMez.Code.FrontEnds.GeneralInterfaceFrame

Advanced wx.Frame with standard containers for interface and control this is meant as a template for GUI design

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentat...

pyMez.Code.FrontEnds.HTMLPanel

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | Examples Home | <a href="../../../Referenc...

pyMez.Code.FrontEnds.IEPanel

A binding to internet explorer through the Wx iewin.IEHtmlWindow, derived in no small part from the work of 11/18/2003 - Jeff Grimmett (grimmtooth@softhome.net)

## Help

`pyMez.Code.FrontEnds`

Documentation Hom...

pyMez.Code.FrontEnds.KeithleyIVPanel

KeithleyIVPanel is a GUI class for taking IV's with the Keithley piccoammeter Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | <a href="../../../Ex...

pyMez.Code.FrontEnds.MatplotlibWxPanel

An example of how to use wx or wxagg in an application with a custom toolbar, Modified to work inside of BOA by AWS. Serves as an advanced plot window for pyMez. The custom tool bar is MyNavigationToolBar

## Help

`pyMez.Code.FrontEnds`

<a href="../../.....

pyMez.Code.FrontEnds.SimpleArbDBLowerInterfacePanel

An interface panel for simple editing of logs, plugs into lower interface container

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | <a href="../....

pyMez.Code.FrontEnds.SimpleLogLowerInterfacePanel

An interface panel for simple editing of logs, plugs into lower interface container Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | <a href="../.....

pyMez.Code.FrontEnds.StyledTextCtrlPanel

pyMez.Code.FrontEnds.VisaDialog

VisaDialog is a very simple dialog for writing and reading commands over GPIB and RS232 Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | <a href="....

pyMez.Code.FrontEnds.WxDialogFunctions

This module contains simple functions for creating wx dialogs and returning import user choices.

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | ...

pyMez.Code.FrontEnds.WxHTML2Panel

A Wx HTML2 panel for full featured HTML support

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | <a href="../../../Examples/html/Examples_Home.ht...

pyMez.Code.FrontEnds.XMLEditPanel

This module defines a simple xml editor that shows the xsl if available

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | <a href="../../../Example...

pyMez.Code.FrontEnds.XMLGeneral

XMLGeneral handles general XML document tasks and is meant to be a Model-View for the General XML editing FrontEnds

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Docume...